@@ -4,7 +4,8 @@ if VERSION < v"0.7-"
     error("Unsupported Julia version $VERSION")
 end
 
-using Pkg
+const Pkg =
+    Base.require(Base.PkgId(Base.UUID("44cfe95a-1eb2-52ea-b672-e2afdf69b78f"), "Pkg"))
 
 Pkg.activate(compiler_env)
 @info "Loading PackageCompiler..."
@@ -13,18 +14,18 @@ using PackageCompiler
 @info "Installing PyCall..."
 Pkg.activate(".")
 Pkg.add([
-    PackageSpec(
+    Pkg.PackageSpec(
         name = "PyCall",
         uuid = "438e738f-606a-5dbb-bf0a-cddfbfd45ab0",
-    )
-    PackageSpec(
-        name = "MacroTools",
-        uuid = "1914dd2f-81c6-5fcd-8719-6d5c9610ff09",
-    )
+    ),
 ])
 
 @info "Compiling system image..."
-sysout, _curr_syso = compile_incremental("Project.toml", script)
+create_sysimage(
+    [:PyCall],
+    sysimage_path = output,
+    project = ".",
+    precompile_execution_file = script,
+)
 
 @info "System image is created at $output"
-cp(sysout, output, force=true)
